@@ -1,11 +1,13 @@
 import pyperclip
 import os
 
+def available_templates():
+    available = ["union_find", "trie"]
+
+    return available
+    
 def union_find():
     curr_path = os.path.dirname(__file__)
-    print(curr_path)
-    return curr_path
-    """
     file_path = os.path.join(curr_path, './union_find.py')
     union_find_code = ""
     with open(file_path, 'r') as f:
@@ -26,4 +28,3 @@ def trie():
     f.close()
     pyperclip.copy(trie_code)
     return trie_code
-"""
\ No newline at end of file
